<?php
/**
 * themefurnace Theme Customizer
 *
 * @package themefurnace
 */

/* Sanitization functions */
function themefurnace_sanitize_slider_options( $value ) {
	if ( !in_array( $value, array( 'enable', 'disable' ) ) ) {
		$value = 'enable';
	}
	return $value;
}

function themefurnace_sanitize_int( $value ) {
	return (int) $value;
}

function themefurnace_sanitize_slider_effect( $value ) {
	if ( !in_array( $value, array( 'slide', 'fade' ) ) ) {
		$value = 'fade';
	}
	return $value;
}

function themefurnace_sanitize_slider_direction( $value ) {
	if ( !in_array( $value, array( 'horizontal', 'vertical' ) ) ) {
		$value = 'horizontal';
	}
	return $value;
}
/* End sanitization functions */

/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function themefurnace_customize_register( $wp_customize )
{
    $wp_customize->get_setting( 'blogname' )->transport = 'postMessage';
    $wp_customize->get_setting( 'blogdescription' )->transport = 'postMessage';
    $wp_customize->get_setting( 'header_textcolor' )->transport = 'postMessage';

    // custom handler - textarea
    class themefurnace_Textarea_Control extends WP_Customize_Control
    {
        public $type = 'textarea';

        public function render_content()
        {
            ?>
            <label>
                <span class="customize-control-title"><?php echo esc_html( $this->label ); ?></span>
                <textarea rows="5"
                          style="width:100%;" <?php $this->link(); ?>><?php echo esc_textarea( $this->value() ); ?></textarea>
            </label>
        <?php
        }
    }

}

add_action( 'customize_register', 'themefurnace_customize_register' );


/**
 * Binds JS handlers to make Theme Customizer preview reload changes asynchronously.
 */
function themefurnace_customize_preview_js()
{
    wp_enqueue_script( 'themefurnace_customizer', get_template_directory_uri() . '/js/customizer.js', array( 'customize-preview' ), '20130508', true );
}

add_action( 'customize_preview_init', 'themefurnace_customize_preview_js' );


function themefurnace_customizer( $wp_customize )
{
    $wp_customize->add_section( 'themefurnacefooter', array(
        'title'       => 'Footer Text', // The title of section
        'priority'    => 50,
        'description' => 'Footer Text', // The description of section
    ) );

    $wp_customize->add_setting( 'themefurnacefooter_footer_text', array(
        'default' => 'Hello world',
		'sanitize_callback' => 'sanitize_text_field',
        // Let everything else default
    ) );
    $wp_customize->add_control( 'themefurnacefooter_footer_text', array(
        // wptuts_welcome_text is a id of setting that this control handles
        'label'   => 'Footer Text',
        // 'type' =>, // Default is "text", define the content type of setting rendering.
        'section' => 'themefurnacefooter', // id of section to which the setting belongs
        // Let everything else default
    ) );


    $wp_customize->add_section( 'themefurnace_logo_section', array(
        'title'       => __( 'Logo', 'themefurnace' ),
        'priority'    => 30,
        'description' => 'Upload a logo to replace the default site name and description in the header',
    ) );


    $wp_customize->add_setting( 'themefurnace_logo', array( 'sanitize_callback' => 'esc_url_raw' ) );
    $wp_customize->add_setting( 'themefurnace_footer_logo', array( 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'themefurnace_logo', array(
        'label'    => __( 'Logo', 'themefurnace' ),
        'section'  => 'themefurnace_logo_section',
        'settings' => 'themefurnace_logo',
    ) ) );

    $wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'footer_themefurnace_logo', array(
        'label'    => __( 'Footer Logo', 'themefurnace' ),
        'section'  => 'themefurnace_logo_section',
        'settings' => 'themefurnace_footer_logo',
    ) ) );

// display X blog posts and Y portfolio items
    $wp_customize->add_section( 'frontpage_items', array(
        'title'    => __( 'Front page items', 'themefurnace' ),
        'priority' => 50,
    ) );


    $wp_customize->add_setting( 'fp_portfolio_items', array(
        'default'    => '4',
        'type'       => 'theme_mod',
        'capability' => 'edit_theme_options',
        'transport'  => 'postMessage',
		'sanitize_callback' => 'themefurnace_sanitize_int',
    ) );

    $wp_customize->add_control( 'fp_portfolio_items', array(
        'label'    => __( 'Number of portfolio items to show on the front page', 'themefurnace' ),
        'section'  => 'frontpage_items',
        'settings' => 'fp_portfolio_items',
        'type'     => 'text',
    ) );

// Portfolio category
    $categories = get_categories();
    $fp_categories = array();

    foreach ( $categories as $category ) {
        $fp_categories[$category->term_id] = $category->name;
    }

    $wp_customize->add_setting( 'fp_portfolio_category', array(
        'type'       => 'theme_mod',
        'capability' => 'edit_theme_options',
        'transport'  => 'postMessage',
		'sanitize_callback' => 'themefurnace_sanitize_int',
    ) );

    $wp_customize->add_control( 'fp_portfolio_category', array(
        'label'    => __( 'Portfolio category', 'themefurnace' ),
        'section'  => 'frontpage_items',
        'settings' => 'fp_portfolio_category',
        'type'     => 'select',
        'choices'  => $fp_categories
    ) );
// end Portfolio category

    $wp_customize->add_setting( 'fp_blog_items', array(
        'default'    => '4',
        'type'       => 'theme_mod',
        'capability' => 'edit_theme_options',
        'transport'  => 'postMessage',
		'sanitize_callback' => 'themefurnace_sanitize_int',
    ) );

    $wp_customize->add_control( 'fp_blog_items', array(
        'label'    => __( 'Number of blog posts to show on the front page', 'themefurnace' ),
        'section'  => 'frontpage_items',
        'settings' => 'fp_blog_items',
        'type'     => 'text',
    ) );


// slider options
// display X blog posts and Y portfolio items
    $wp_customize->add_section( 'frontpage_slider_options', array(
        'title'    => __( 'Front page slider', 'themefurnace' ),
        'priority' => 50,
    ) );

    $wp_customize->add_setting( 'fp_slider_enable', array(
        'default'    => 'enable',
        'type'       => 'theme_mod',
        'capability' => 'edit_theme_options',
        'transport'  => 'postMessage',
		'sanitize_callback' => 'themefurnace_sanitize_slider_options',
    ) );

    $wp_customize->add_control( 'fp_slider_enable', array(
        'label'    => __( 'Enable/Disable the slider', 'themefurnace' ),
        'section'  => 'frontpage_slider_options',
        'settings' => 'fp_slider_enable',
        'type'     => 'radio',
        'choices'  => array(
            'enable'  => __( 'Enable', 'themefurnace' ),
            'disable' => __( 'Disable', 'themefurnace' ),
        )
    ) );

    $wp_customize->add_setting( 'fp_slider_items', array(
        'default'    => '4',
        'type'       => 'theme_mod',
        'capability' => 'edit_theme_options',
        'transport'  => 'postMessage',
		'sanitize_callback' => 'themefurnace_sanitize_int',
    ) );

    $wp_customize->add_control( 'fp_slider_items', array(
        'label'    => __( 'Number of items to show in the slider', 'themefurnace' ),
        'section'  => 'frontpage_slider_options',
        'settings' => 'fp_slider_items',
        'type'     => 'text',
    ) );

// Slider category
    $wp_customize->add_setting( 'fp_slider_category', array(
        'type'       => 'theme_mod',
        'capability' => 'edit_theme_options',
        'transport'  => 'postMessage',
		'sanitize_callback' => 'themefurnace_sanitize_int',
    ) );

    $wp_customize->add_control( 'fp_slider_category', array(
        'label'    => __( 'Slider category', 'themefurnace' ),
        'section'  => 'frontpage_slider_options',
        'settings' => 'fp_slider_category',
        'type'     => 'select',
        'choices'  => $fp_categories
    ) );
// end Slider category

    $wp_customize->add_setting( 'fp_slider_transition_effect', array(
        'default'    => 'fade',
        'type'       => 'theme_mod',
        'capability' => 'edit_theme_options',
        'transport'  => 'postMessage',
		'sanitize_callback' => 'themefurnace_sanitize_slider_effect',
    ) );

    $wp_customize->add_control( 'fp_slider_transition_effect', array(
        'label'    => __( 'Transition Effect', 'themefurnace' ),
        'section'  => 'frontpage_slider_options',
        'settings' => 'fp_slider_transition_effect',
        'type'     => 'select',
        'choices'  => array(
            'fade'  => __( 'Fade', 'themefurnace' ),
            'slide' => __( 'Slide', 'themefurnace' ),
        )
    ) );

    $wp_customize->add_setting( 'fp_slider_slide_direction', array(
        'default'    => 'horizontal',
        'type'       => 'theme_mod',
        'capability' => 'edit_theme_options',
        'transport'  => 'postMessage',
		'sanitize_callback' => 'themefurnace_sanitize_slider_direction',
    ) );

    $wp_customize->add_control( 'fp_slider_slide_direction', array(
        'label'    => __( 'Slide Direction', 'themefurnace' ),
        'section'  => 'frontpage_slider_options',
        'settings' => 'fp_slider_slide_direction',
        'type'     => 'select',
        'choices'  => array(
            'horizontal' => __( 'Horizontal', 'themefurnace' ),
            'vertical'   => __( 'Vertical', 'themefurnace' ),
        )
    ) );

    $wp_customize->add_setting( 'fp_slider_animation_speed', array(
        'default'    => '500',
        'type'       => 'theme_mod',
        'capability' => 'edit_theme_options',
        'transport'  => 'postMessage',
		'sanitize_callback' => 'themefurnace_sanitize_int',
    ) );

    $wp_customize->add_control( 'fp_slider_animation_speed', array(
        'label'    => __( 'Animation Speed', 'themefurnace' ),
        'section'  => 'frontpage_slider_options',
        'settings' => 'fp_slider_animation_speed',
        'type'     => 'text',
    ) );

    $wp_customize->add_setting( 'fp_slider_pause_time', array(
        'default'    => '3000',
        'type'       => 'theme_mod',
        'capability' => 'edit_theme_options',
        'transport'  => 'postMessage',
		'sanitize_callback' => 'themefurnace_sanitize_int',
    ) );

    $wp_customize->add_control( 'fp_slider_pause_time', array(
        'label'    => __( 'Pause Time', 'themefurnace' ),
        'section'  => 'frontpage_slider_options',
        'settings' => 'fp_slider_pause_time',
        'type'     => 'text',
    ) );
}

add_action( 'customize_register', 'themefurnace_customizer', 11 );

function themefurnace_customizer_live_preview()
{
    wp_enqueue_script(
        'themefurnace-themecustomizer', //Give the script an ID
        get_template_directory_uri() . '/js/customizer.js', //Point to file
        array( 'jquery', 'customize-preview' ), //Define dependencies
        '', //Define a version (optional)
        true //Put script in footer?
    );
}

add_action( 'customize_preview_init', 'themefurnace_customizer_live_preview' );