<?php
/**
 * Code taken from Responsive Slider for Developers by Hal Gatewood
 */

// GET ROTATORS:
function themefurnace_flexslider_hg_rotators()
{
	$rotators = array();

	$options = '{';
	$options .= 'animation: "' . esc_js( get_theme_mod( 'fp_slider_transition_effect', 'fade' ) ) . '",';
	$options .= 'direction: "' . esc_js( get_theme_mod( 'fp_slider_slide_direction', 'horizontal' ) ) . '",';
	$options .= 'animationSpeed: ' . (int)get_theme_mod( 'fp_slider_animation_speed', '500' ) . ',';
	$options .= 'slideshowSpeed: ' . (int)get_theme_mod( 'fp_slider_pause_time', '3000' );
	$options .= '}';

	$rotators['homepage'] = array(
		'size'    => 'homepage-rotator',
		'limit'   => (int)get_theme_mod( 'fp_slider_items', 3 ),
		'options' => $options,
	);

	return apply_filters( 'themefurnace_flexslider_hg_rotators', $rotators );
}


// SHOW ROTATOR
function themefurnace_show_flexslider_rotator( $slug )
{
	// homepage slider can be disabled using WP customizer
	if ( $slug == 'homepage' ) {
		if ( get_theme_mod( 'fp_slider_enable', 'enable' ) == 'disable' ) {
			return;
		}

	}
	$slider_category = esc_html( get_theme_mod( 'fp_slider_category' ) );

	if ( empty( $slider_category ) ) {
		return;
	}


	// GET ALL ROTATORS
	$rotators = themefurnace_flexslider_hg_rotators();

	// SET IMAGE SIZE: size
	$image_size = isset( $rotators[$slug]['size'] ) ? $rotators[$slug]['size'] : 'large';

	// HIDE SLIDE TEXT: hide_slide_data
	$hide_slide_data = isset( $rotators[$slug]['hide_slide_data'] ) ? true : false;

	// HEADING HTML ELEMENT: heading_tag
	$header_type = isset( $rotators[$slug]['heading_tag'] ) ? $rotators[$slug]['heading_tag'] : "h1";

	// ORDER BY PARAMS: orderby, order, limit
	$orderby = isset( $rotators[$slug]['orderby'] ) ? $rotators[$slug]['orderby'] : "menu_order";
	$order = isset( $rotators[$slug]['order'] ) ? $rotators[$slug]['order'] : "ASC";

	$limit = isset( $rotators[$slug]['limit'] ) ? $rotators[$slug]['limit'] : "-1";

	// DEFAULT QUERY PARAMS
	$query_args = array( 'cat' => (int)$slider_category, 'order' => $order, 'orderby' => $orderby, 'posts_per_page' => $limit );

	// IF ATTACHMENTS WE NEED THE POST PARENT
	if ( $slug == "attachments" ) {
		$query_args['post_type'] = 'attachment';
		$query_args['post_parent'] = get_the_ID();
		$query_args['post_status'] = 'inherit';
		$query_args['post_mime_type'] = 'image';
		unset( $query_args['meta_value'] );
		unset( $query_args['meta_key'] );
	}

	$rtn = "";

	query_posts( apply_filters( 'flexslider_hg_query_post_args', $query_args ) );
	if ( have_posts() ) {
		$rtn .= '<div id="flexslider_hg_' . $slug . '_wrapper" class="flexslider-hg-wrapper">';
		$rtn .= '<div id="flexslider_hg_' . $slug . '" class="flexslider_hg_' . $slug . ' flexslider flexslider-hg">';
		$rtn .= '<ul class="slides">';

		while ( have_posts() ) {
			the_post();

			$url = get_post_meta( get_the_ID(), "_slide_link_url", true );
			$a_tag_opening = '<a href="' . $url . '" title="' . the_title_attribute( array( 'echo' => false ) ) . '" >';


			$rtn .= '<li>';
			if ( !$hide_slide_data ) {
				$rtn .= '<div class="slide-data">';

				$rtn .= '<' . $header_type . ' class="slide-title flexslider-hg-title">';

				if ( $url ) {
					$rtn .= $a_tag_opening;
				}
				$rtn .= get_the_title();
				if ( $url ) {
					$rtn .= '</a>';
				}

				$rtn .= '</' . $header_type . '>';

				$rtn .= get_the_excerpt();
				$rtn .= '</div>';
			}
			$rtn .= '<div id="slide-' . get_the_ID() . '" class="slide">';

			if ( $slug == "attachments" ) {
				$rtn .= wp_get_attachment_image( get_the_ID(), $image_size );
			} else if ( has_post_thumbnail() ) {
				if ( $url ) {
					$rtn .= $a_tag_opening;
				}
				$rtn .= get_the_post_thumbnail( get_the_ID(), $image_size, array( 'class' => 'slide-thumbnail' ) );
				if ( $url ) {
					$rtn .= '</a>';
				}
			}


			$rtn .= '</div><!-- #slide-' . get_the_ID() . ' -->';
			$rtn .= '</li>';
		}

		$rtn .= '</ul>';
		$rtn .= '</div><!-- close: #flexslider_hg_' . $slug . ' -->';
		$rtn .= '</div><!-- close: #flexslider_hg_' . $slug . '_wrapper -->';

		update_option( 'themefurnace_flexslider_options_' . $slug, $rotators[$slug]['options'] );
		update_option( 'themefurnace_flexslider_slug', $slug );
	}

	wp_reset_query();

	return $rtn;
}

function themefurnace_flexslider_init()
{
	$slug = get_option( 'themefurnace_flexslider_slug' );
	$options = get_option( 'themefurnace_flexslider_options_' . $slug );

	if ( empty( $slug ) ) {
		return;
	}

	// INIT THE ROTATOR
	$html = '<script>';
	$html .= " jQuery('#flexslider_hg_{$slug}').flexslider( ";

	if ( isset( $options ) && $options != '' ) {
		$html .= $options;
	}

	$html .= " ); ";
	$html .= '</script>';
	echo $html;
}

add_action( 'wp_footer', 'themefurnace_flexslider_init' );